==> kathra-appmanager-interface-1.0.0-sources.jar: org/kathra/appmanager/service/PipelinesService.java <==
/* 
 * Copyright 2019 The Kathra Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Contributors:
 *
 *    IRT SystemX (https://www.kathra.org/)    
 *
 */
package org.kathra.appmanager.service;

import org.kathra.core.model.Build;
import java.util.List;
import org.kathra.iface.KathraAuthRequestHandler;

public interface PipelinesService extends KathraAuthRequestHandler {

    /**
    * Execute pipeline
    * 
    * @param pipelineId The ID of the Pipeline to get the builds of (required)
    * @param branch The name of the branch to get the builds of (required)
    * @return Build
    */
    Build executePipeline(String pipelineId, String branch) throws Exception;

    /**
    * Get the builds for the given pipeline for a given branch
    * 
    * @param pipelineId The ID of the Pipeline to get the builds of (required)
    * @param branch The name of the branch to get the builds of (required)
    * @return List<Build>
    */
    List<Build> getPipelineBuildsForBranch(String pipelineId, String branch) throws Exception;

}

==> kathra-appmanager-interface-1.2.0-sources.jar: org/kathra/appmanager/service/PipelinesService.java <==
/*
 * Copyright (c) 2020. The Kathra Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Contributors:
 *    IRT SystemX (https://www.kathra.org/)
 *
 */

package org.kathra.appmanager.service;

import org.kathra.core.model.Build;
import java.util.List;

public interface PipelinesService extends org.kathra.iface.KathraAuthRequestHandler {

    /**
    * Execute pipeline
    * 
    * @param pipelineId The ID of the Pipeline to get the builds of (required)
    * @param branch The name of the branch to get the builds of (required)
    * @return Build
    */
    Build executePipeline(String pipelineId, String branch) throws Exception;

    /**
    * Get the builds for the given pipeline for a given branch
    * 
    * @param pipelineId The ID of the Pipeline to get the builds of (required)
    * @param branch The name of the branch to get the builds of (required)
    * @return List<Build>
    */
    List<Build> getPipelineBuildsForBranch(String pipelineId, String branch) throws Exception;

}
